@@ -1,4 +1,9 @@
+"""
+Experiment to test maximum BSON document size with MongoDB emitter
+"""
+import uuid
 import random
+
 from vivarium.core.engine import Engine
 from vivarium.core.process import Process
 from vivarium.core.composer import Composer
@@ -22,9 +27,9 @@ class ManyParametersProcess(Process):
         super().__init__(random_parameters)
 
     def ports_schema(self):
-        return {'port': {'variable': {'_default': 0}}}
+        return {'port': {'variable': {'_default': 0, '_emit': True}}}
     def next_update(self, timestep, states):
-        return {}
+        return {'port': {'variable': 1}}
 
 
 class ManyParametersComposite(Composer):
@@ -39,7 +44,6 @@ class ManyParametersComposite(Composer):
             for key in range(self.config['number_of_processes'])]
 
     def generate_processes(self, config):
-
         # make a bunch of processes
         return {
             process_id: ManyParametersProcess({
@@ -49,10 +53,14 @@ class ManyParametersComposite(Composer):
 
     def generate_topology(self, config):
         return {
-            process_id: {'port': ('store',)}
+            process_id: {'port': ('store', process_id,)}
             for process_id in self.process_ids}
 
 def run_large_initial_emit():
+    """
+    This experiment runs a large experiment to test the database emitter.
+    This requires MongoDB to be configured and running.
+    """
 
     config = {
         'number_of_processes': 1000,
@@ -62,7 +70,9 @@ def run_large_initial_emit():
     composite = composer.generate()
 
     settings = {
-        'emitter': 'database'
+        'experiment_name': 'large database experiment',
+        'experiment_id': f'large_{str(uuid.uuid4())}',
+        'emitter': 'database',
     }
 
     experiment = Engine({
@@ -70,11 +80,20 @@ def run_large_initial_emit():
         'topology': composite['topology'],
         **settings})
 
-    # retrieve the data
+    # run the experiment
+    experiment.update(10)
+
+    # retrieve the data with data_from_database
     experiment_id = experiment.experiment_id
+
+    # retrieve the data from emitter
+    data = experiment.emitter.get_data()
+    assert list(data.keys()) == [
+        0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0]
+
+    # retrieve the data directly from database
     db = get_experiment_database()
     data, experiment_config = data_from_database(experiment_id, db)
-
     assert 'processes' in experiment_config
     assert 0.0 in data
 
